import { Class, Query } from '@nestjs-query/core';
import { Repository, SelectQueryBuilder, ObjectLiteral } from 'typeorm';
import { RelationMetadata } from 'typeorm/metadata/RelationMetadata';
import { FilterQueryBuilder } from './filter-query.builder';
interface JoinCondition {
    leftHand: string;
    rightHand: string;
}
interface JoinColumn {
    target: Class<unknown> | string;
    alias: string;
    conditions: JoinCondition[];
}
declare type WhereCondition = {
    sql: string;
    params: ObjectLiteral;
};
interface RelationQuery<Relation, Entity> {
    from: Class<Relation>;
    fromAlias: string;
    joins: JoinColumn[];
    whereCondition(entity: Entity): WhereCondition;
}
/**
 * @internal
 *
 * Class that will convert a Query into a `typeorm` Query Builder.
 */
export declare class RelationQueryBuilder<Entity, Relation> {
    readonly repo: Repository<Entity>;
    readonly relation: string;
    private relationMetadata;
    readonly filterQueryBuilder: FilterQueryBuilder<Relation>;
    readonly relationRepo: Repository<Relation>;
    constructor(repo: Repository<Entity>, relation: string);
    select(entity: Entity, query: Query<Relation>): SelectQueryBuilder<Relation>;
    private createRelationQueryBuilder;
    private get relationMeta();
    getManyToOneOrOneToOneOwnerMeta(relation: RelationMetadata): RelationQuery<Relation, Entity>;
    getOneToManyOrOneToOneNotOwnerMeta(relation: RelationMetadata): RelationQuery<Relation, Entity>;
    getManyToManyOwnerMeta(relation: RelationMetadata): RelationQuery<Relation, Entity>;
    getManyToManyNotOwnerMetadata(relation: RelationMetadata): RelationQuery<Relation, Entity>;
}
export {};
